#
# spec file for package python-characteristic
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-characteristic
Version:        14.3.0
Release:        5.1
Summary:        Python class decorator to implement attribute-related object protocols
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/hynek/characteristic/
Source:         https://files.pythonhosted.org/packages/source/c/characteristic/characteristic-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This is a Python package with class decorators that ease the chores of
implementing the most common attribute-related object protocols.

The developer has to specify the attributes to work with, and
python-characteristic gives:

- a human-readable __repr__,
- a complete set of comparison methods,
- and a kwargs-based initializer (that cooperates with existing ones)

without writing boilerplate code.

%prep
%setup -q -n characteristic-%{version}

%build
%python_build

%install
%python_install

%check
%python_expand py.test-%{$python_bin_suffix} test_characteristic.py

%files %{python_files}
%license LICENSE
%doc AUTHORS.rst README.rst
%pycache_only %{python_sitelib}/__pycache__/*
%{python_sitelib}/characteristic.py*
%pycache_only %{python_sitelib}/__pycache__/*
%{python_sitelib}/test_characteristic.py*
%{python_sitelib}/characteristic-%{version}-py*.egg-info

%changelog
* Fri Jan  4 2019 jengelh@inai.de
- Trim rhetorics from description.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Thu Mar 26 2015 termim@gmail.com
- update to version 14.3.0:
  * All decorators now gracefully accept empty attribute lists. [22].
- changes from version 14.2.0:
  * Attributes set by :func:`characteristic.attributes` are now stored
    on the class as well. [20]
  * __init__ methods that are created by
    :func:`characteristic.with_init` are now generated on the fly and
    optimized for each class. [9]
- changes from version 14.1.0:
  * Fix stray deprecation warnings.
  * Don't rely on warnings being switched on by command line. [17]
- changes from version 14.0.0:
  * Deprecations:
    + The defaults argument of :func:`~characteristic.with_init` and
    :func:`~characteristic.attributes` has been deprecated in favor
    of the new explicit :class:`~characteristic.Attribute` class and
    it's superior default_value and default_factory arguments.
    + The create_init argument of :func:`~characteristic.attributes`
    has been deprecated in favor of the new apply_with_init argument
    for the sake of consistency.
  * Changes:
    +  Switch to a year-based version scheme.
    + Add :func:`~characteristic.immutable` to make certain attributes
    of classes immutable. Also add apply_immutable argument to
    :func:`~characteristic.attributes`. [14]
    + Add explicit :class:`~characteristic.Attribute` class and use it
    for default factories. [8]
    + Add aliasing of private attributes for
    :func:`~characteristic.with_init`?s initializer when used
    together with :class:`~characteristic.Attribute`. Allow for
    custom aliasing via a callable. [6, 13]
    + Add type checks to :func:`~characteristic.with_init`?s
    initializer. [12]
    + Add possibility to hand-pick which decorators are applied from
    within :func:`~characteristic.attributes`.
    + Add possibility to exclude single attributes from certain
    decorators.
* Wed Jul 30 2014 toddrme2178@gmail.com
- Initial version
